@@ -18,6 +18,8 @@
 
 #define G_LOG_DOMAIN "dzl-shortcut-theme"
 
+#include "config.h"
+
 #include <string.h>
 
 #include "shortcuts/dzl-shortcut-context.h"
@@ -239,7 +241,7 @@ load_state_commit_property (LoadState  *state,
                            state->stack->pspec->name,
                            &value);
 
-  g_string_free (state->text, FALSE);
+  g_string_free (state->text, TRUE);
   state->text = NULL;
 }
 
